(* bkp-main.ml - driver for standalone bkp utility
 * Copyright (C) 2000, 2001, 2002, 2003 Ed L. Cashin
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *)

let basename s = 
  let slashpos = try 
    (String.rindex s '/') + 1
  with
    Not_found -> 0 in
  String.sub s slashpos ((String.length s) - slashpos)
;;

let usage output =
  Printf.fprintf output
    "usage: %s {filename} [filename2] ...\n" (basename Sys.argv.(0))
;;

let main () = 
  let argc = Array.length Sys.argv in
  if argc < 2 then
    (usage stderr; exit 1)
  else
    ();
  let files = ArrayLabels.sub Sys.argv ~pos:1 ~len:(argc - 1) in
  try 
    Array.iter Bkp.bkp files
  with
    Unix.Unix_error (errno,fnname,args) -> (
      Printf.fprintf stderr "%s Error: %s %s: %s\n"
	(basename Sys.argv.(0)) fnname args (Unix.error_message errno);
      exit 1
     )
;;

main ()
;;
