(* bkp.ml - create dated copy of file
 * Copyright (C) 2000, 2001, 2002, 2003 Ed L. Cashin
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *)

let bkp_fname fname extbase counter = 
  fname ^ "." ^ if counter = 0 then 
    extbase 
  else
    extbase ^ "_" ^ (string_of_int counter)
;;

let rec find_bkpname ?(count = 0) fname extbase perm = 
  try 
    let bkpname = bkp_fname fname extbase count
    and fd = 
      Unix.openfile
	(bkp_fname fname extbase count)
	[Unix.O_EXCL;Unix.O_CREAT;Unix.O_TRUNC;Unix.O_WRONLY] perm;
    in (bkpname, fd)
  with Unix.Unix_error (Unix.EEXIST, _, _) ->
    find_bkpname ~count:(count + 1) fname extbase perm
;;

(* copy data from a to b *)
let rec write_all ~buf ~n ?(pos = 0) fd = 
  let n_written = UnixLabels.write fd ~buf:buf ~pos:pos ~len:n in
  if n_written < n then
    write_all ~buf ~pos:(pos + n_written) ~n:(n - n_written) fd
  else ()
;;

let copy_contents ~from_fd:a ~to_fd:b =
  let bufsiz = 1024 in
  let buf = (String.create bufsiz) and
      finished = ref false in
  while not !finished do
    let n = UnixLabels.read a ~buf:buf ~pos:0 ~len:bufsiz in
    if n = 0 then 
      finished := true
    else
      write_all ~buf:buf ~n:n b
  done
;;

let bkp ?(date = (Unix.localtime (Unix.time ()))) fname =
  let origfd = Unix.openfile fname [Unix.O_RDONLY] 0400 in
  let perm = (Unix.fstat origfd).Unix.st_perm
  and extbase = 
    Printf.sprintf
      "%04d%02d%02d" 
      (date.Unix.tm_year + 1900) (date.Unix.tm_mon + 1) date.Unix.tm_mday in
  let (bkpname, bkpfd) = find_bkpname fname extbase perm in
  (Printf.printf "%s -> %s\n" fname bkpname;
   copy_contents ~from_fd:origfd ~to_fd:bkpfd)
;;

