# /*
# oinst - software installation management tool
# Copyright (C) 2000, 2001, 2002 Ed L. Cashin
# 
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
# 
# */

# makefile - top level makefile sets things up for secondary make (build.mak),
#            including producing the C source files generated by re2c and bison.
# 
# You can see what each target here is for by reading the echo'ed message.
# 

PROG = oinst
CC = gcc
CPPFLAGS = -I.
CFLAGS = -W -Wall -g
SOURCES = main.c elcwft.c xstrdup.c xstradd.c elcerror.c
GENERATED_SOURCES = # parse/grammar.tab.c parse/lex.c parse/keyword.c
.PHONY : clean realclean prep shell

# principal target: build the principal
# 
principal : prep
	@echo '----------running second-level make to build program'
	${MAKE} -f make.d/build.mak CC="${CC}" PROG=${PROG} LIBS=${LIBS}

prep : make.d/dep.mak make.d/obj.mak make.d/build.mak make.d/settings.sh \
	${GENERATED_SOURCES}

# parse/lex.c : parse/lex.re
# 	${MAKE} ${RE2C}/re2c
# 	${RE2C}/re2c parse/lex.re > parse/lex.c

make.d/settings.sh : makefile 
	@echo '----------creating settings for compile.sh'
	echo "# make.d/settings.sh - generated by makefile" > make.d/settings.sh
	echo cc=${CC} >> make.d/settings.sh
	echo progname=${PROG} >> make.d/settings.sh
	echo cflags='"'${CFLAGS}'"' >> make.d/settings.sh
	echo cppflags='"'${CPPFLAGS}'"' >> make.d/settings.sh
	echo defs='"'${DEFS}'"' >> make.d/settings.sh

make.d/dep.mak : ${SOURCES} makefile make.d/depgen 
	@echo '----------creating dependency list for build.mak'
	CC=${CC} PROGNAME=${PROGNAME} CPPFLAGS="${CPPFLAGS}" \
	 make.d/depgen ${SOURCES} > make.d/dep.mak

make.d/obj.mak : makefile
	@echo '----------creating object file list for build.mak'
	echo "OBJ = ${SOURCES} " | sed 's!\.c !.o !g' > make.d/obj.mak

realclean : clean
	@echo '----------cleaning top-level generated files'
	rm -f make.d/dep.mak make.d/obj.mak make.d/settings.sh
	rm -f parse/grammar.tab.c parse/grammar.tab.h parse/grammar.output 

clean : make.d/obj.mak make.d/dep.mak
	rm -f make.d/settings.sh
	@echo '----------running second-level make to clean'
	${MAKE} -f make.d/build.mak clean PROG=${PROG}

